=======
spharpy
=======

.. image:: https://badge.fury.io/py/spharpy.svg
    :target: https://badge.fury.io/py/spharpy
.. image:: https://readthedocs.org/projects/spharpy/badge/?version=latest
    :target: https://spharpy.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
.. image:: https://circleci.com/gh/mberz/spharpy.svg?style=shield
    :target: https://circleci.com/gh/mberz/spharpy
.. image:: https://mybinder.org/badge_logo.svg
    :target: https://mybinder.org/v2/gh/mberz/spharpy/main?filepath=examples/

Spherical array processing in python.


Installation
============

Use pip to install spharpy

.. code-block:: console

    $ pip install spharpy


Getting Started
===============

Check out the `example notebooks`_ - also available on `mybinder.org`_ - for a tour of basic functionality and
`read the docs`_ for the complete documentation.


Contributing
============

Refer to the `contribution guidelines`_ for more information.


.. _contribution guidelines: https://github.com/mberz/spharpy/blob/main/CONTRIBUTING.rst
.. _example notebooks: https://github.com/mberz/spharpy/blob/main/examples
.. _mybinder.org: https://mybinder.org/v2/gh/mberz/spharpy/main?filepath=examples/
.. _read the docs: https://spharpy.readthedocs.io/en/latest
